@@ -38,7 +38,9 @@ __all__ = (
     "RouteTypeType",
     "ServiceEndpointTypeType",
     "ServiceStateType",
+    "MigrationHubRefactorSpacesServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -94,6 +96,7 @@ RouteStateType = Literal["ACTIVE", "CREATING", "DELETING", "FAILED", "INACTIVE",
 RouteTypeType = Literal["DEFAULT", "URI_PATH"]
 ServiceEndpointTypeType = Literal["LAMBDA", "URL"]
 ServiceStateType = Literal["ACTIVE", "CREATING", "DELETING", "FAILED"]
+MigrationHubRefactorSpacesServiceName = Literal["migration-hub-refactor-spaces"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -247,6 +250,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -395,6 +399,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "list_applications",
     "list_environment_vpcs",
